========
Examples
========

Create and submit jobs
----------------------

.. literalinclude:: ../examples/submit.py
   :language: python


Check jobs
----------

.. literalinclude:: ../examples/check.py
   :language: python
